# -------------------------------------------------------------------------------------
# flo::plugin::Photo
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@cisedi.com).
#    Copyright : (c) MKDoc Holdings Ltd, 2001
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden
#
#    Description:
#
#      A plugin that is used to collect votes from Photo components, send cookies
#      to the navigators which have voted, and display results
#
# -------------------------------------------------------------------------------------
package flo::plugin::Photo;
use flo::Template;
use flo::HTTP::Date;
use flo::Object;
use lib::sql::Table;
use lib::cgi::CGI;
use flo::Standard;
use lib::Exception;
use flo::HTTP::Header;
use strict;
use vars qw /@ISA/;
@ISA = qw /flo::Object/;


sub main
{
    my $class = shift;
    my $document_table = table ('Document');
    my $cgi = cgi;
    
    # if this module is not concerned, let's return ASAP
    my $config = $class->config;
    my $http_name = $config->{http_name};
    my $q_http_name = quotemeta ($http_name);
    my $raw_path_info = raw_path_info;
    my ($photo_id) = $raw_path_info =~ /.*\/(\d+)_$q_http_name$/;
    return unless (defined $photo_id and $photo_id);
    
    # otherwise, let's process the request
    $raw_path_info =~ s/\/(\d+)_$q_http_name$//;
    $raw_path_info .= '/';
    
    # clean path info so that we know which document we really want to
    # work with
    my $path_info = path_info;
    if ($path_info ne '/')
    {
	$path_info =~ s/^\///;
	$path_info =~ s/\/$//;
	my @path_info = split /\//, $path_info;
	pop (@path_info);
	if (@path_info) { $path_info = '/' . (join '/', @path_info) . '/' }
	else { $path_info = '/' }
    }
    
    # get the current document. If it does not exist, let's pass the query to the 404
    my $document = $document_table->get ( Full_Path => $path_info ) or return;
    
    # we must parse the document contents only if we have just
    # entered into edition mode
    my $editor = new flo::Editor ( cgi => cgi );
    $editor->parse_xml ( $document->{Body} );
    
    # get all the photo components for which an image has been uploaded
    my @photos   = $editor->access ( class  => [ 'photo' ] );
    @photos = map { (defined $_->{image} and $_->{image}) ? $_ : () } @photos;
    
    my ($photo, $photo_prev, $photo_next);
    my $found = 0;
    return unless (defined $photo_id and $photo_id);
    for (my $i=0; $i < @photos; $i++)
    {
	$photo = $photos[$i];
	$photo_prev = ($i == 0) ? undef : $photos[$i-1];
	$photo_next = ($i == @photos) ? undef : $photos[$i+1];
	if ($photo->{image} =~ /^\Q$photo_id\E\//)
	{
	    $found = 1;
	    last;
	}
    }
    
    return unless ($found);
    
    my $hash = {
	Document => $document,
	Photo => $photo,
	Photo_Prev => $photo_prev,
	Photo_Next => $photo_next,
    };
    
  flo::HTTP::Header->out
      ( new flo::Template ( file => template ('photo', $document->Lang),
			    hash => $hash ) );
    return 'TERMINATE';
}
